@@ -2,6 +2,11 @@
 # -*- coding: utf-8 -*-
 
 import os
+import random
+import platform
+from uuid import getnode as get_mac
+
+from allo.model.config import AlloConfig
 
 TELEPORT_SHA = "786e399511525889778d2a3e64bc5d18f7ecddf6eaac684c224249657f404b76" \
     if os.getenv("ALLOENV") == "TEST" \
@@ -23,3 +28,12 @@ CODEPRODUIT = {
     "i-Parapheur": "IP",
     "Pastell": "PA"
 }
+
+
+def getnode():
+    config = AlloConfig.load()
+    if hasattr(config, "id_client"):
+        return config.id_client
+    else:
+        random.seed(platform.node() + get_mac())
+        return str(random.randint(1, 9999999)).zfill(7)
